RequestBodyConnection

Struct RequestBodyConnection 

pub struct RequestBodyConnection<'r, R: Read> { /* private fields */ }
The connection reading the request body. Can be used to read the request body and then extract the underlying connection for reading further data, such as if the connenction has been upgraded.

Implementations

Source

impl<'r, R: Read> RequestBodyConnection<'r, R>

pub const fn content_length(&self) -> usize

Return the total length of the body

pub fn body(&mut self) -> RequestBody<'_, R>

Return the Request Body

pub async fn finalize( self, ) -> Result<Connection<'r, impl Read<Error = R::Error> + 'r>, R::Error>

“Finalize” the connection, returning the underlying connection. Also cancels the read timeout to avoid long-lived connections such as WebSockets triggering it.