EventWriter

Struct EventWriter 

pub struct EventWriter<'a, W: Write> { /* private fields */ }
Writing events to an EventWriter will send the events to the client.

Implementations

Source

impl<W: Write> EventWriter<'_, W>

pub async fn write_keepalive(&mut self) -> Result<(), W::Error>

Send an event with an empty name, keeping the connection alive.

pub async fn write_event<T: EventData>( &mut self, event: &str, data: T, ) -> Result<(), W::Error>

Send an event with a given name and data.