pub struct RequestBodyConnection<'r, R: Read> { /* private fields */ }Expand description
The connection reading the request body. Can be used to read the request body and then extract the underlying connection for reading further data, such as if the connenction has been upgraded.
Implementations
Sourceimpl<'r, R: Read> RequestBodyConnection<'r, R>
impl<'r, R: Read> RequestBodyConnection<'r, R>
Sourcepub const fn content_length(&self) -> usize
pub const fn content_length(&self) -> usize
Return the total length of the body
Sourcepub fn body(&mut self) -> RequestBody<'_, R>
pub fn body(&mut self) -> RequestBody<'_, R>
Return the Request Body